window.Gleam.initSearch([{"doc":"lustre","title":"lustre","content":"# Lustre\n\nAn Elm-inspired framework for building web apps in Gleam!\n\n---\n\n[![Package Version](https://img.shields.io/hexpm/v/lustre)](https://hex.pm/packages/lustre)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/lustre/)\n\n```gleam\nimport gleam/int\nimport lustre\nimport lustre/element.{button, div, p, text}\nimport lustre/event.{on_click}\nimport lustre/cmd\n\npub fn main() {\n  let app = lustre.simple(init, update, render)\n  let assert Ok(_) = lustre.start(app, &quot;#app&quot;)\n\n  Nil\n}\n\nfn init() {\n  0\n}\n\ntype Msg {\n  Incr\n  Decr\n}\n\nfn update(state, msg) {\n  case msg {\n    Incr -&gt; state + 1\n    Decr -&gt; state - 1\n  }\n}\n\nfn render(state) {\n  div(\n    [],\n    [\n      button([on_click(Decr)], [text(&quot;-&quot;)]),\n      p([], [text(int.to_string(state))]),\n      button([on_click(Incr)], [text(&quot;+&quot;)]),\n    ],\n  )\n}\n```\n\n---\n\n❗️ This package relies on Gleam&#39;s JavaScript FFI and is intended to be run in\nthe browser. **It will not work if your are targetting Node.js or Erlang.**\n\n---\n\n## Installation\n\nLustre is available on [Hex](https://hex.pm/packages/lustre). You can install\nit like any other Hex package:\n\n```sh\n$ gleam add lustre\n```\n","url":"index.html"},{"doc":"lustre/attribute","title":"Attribute","content":"pub opaque type Attribute(msg)\n Attributes are attached to specific elements. They&#39;re either key/value pairs\n or event handlers.\n\n\nSynonyms:\nlustre/attribute.Attribute\nlustre/attribute Attribute","url":"lustre/attribute.html#Attribute"},{"doc":"lustre/attribute","title":"accept","content":"pub fn accept(types: List(String)) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.accept\nlustre/attribute accept","url":"lustre/attribute.html#accept"},{"doc":"lustre/attribute","title":"accept_charset","content":"pub fn accept_charset(types: List(String)) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.accept_charset\nlustre/attribute accept_charset","url":"lustre/attribute.html#accept_charset"},{"doc":"lustre/attribute","title":"alt","content":"pub fn alt(text: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.alt\nlustre/attribute alt","url":"lustre/attribute.html#alt"},{"doc":"lustre/attribute","title":"attribute","content":"pub fn attribute(name: String, value: String) -&gt; Attribute(a)\n\n Lustre does some work internally to convert common Gleam values into ones that\n make sense for JavaScript. Here are the types that are converted:\n \n   - `List(a)` -&gt;  `Array(a)`\n   - `Some(a)` -&gt;  `a`\n   - `None`    -&gt;  `undefined`\n   \nSynonyms:\nlustre/attribute.attribute\nlustre/attribute attribute","url":"lustre/attribute.html#attribute"},{"doc":"lustre/attribute","title":"autocomplete","content":"pub fn autocomplete(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.autocomplete\nlustre/attribute autocomplete","url":"lustre/attribute.html#autocomplete"},{"doc":"lustre/attribute","title":"autofocus","content":"pub fn autofocus(should_autofocus: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.autofocus\nlustre/attribute autofocus","url":"lustre/attribute.html#autofocus"},{"doc":"lustre/attribute","title":"autoplay","content":"pub fn autoplay(should_autoplay: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.autoplay\nlustre/attribute autoplay","url":"lustre/attribute.html#autoplay"},{"doc":"lustre/attribute","title":"checked","content":"pub fn checked(is_checked: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.checked\nlustre/attribute checked","url":"lustre/attribute.html#checked"},{"doc":"lustre/attribute","title":"class","content":"pub fn class(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.class\nlustre/attribute class","url":"lustre/attribute.html#class"},{"doc":"lustre/attribute","title":"classes","content":"pub fn classes(names: List(#(String, Bool))) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.classes\nlustre/attribute classes","url":"lustre/attribute.html#classes"},{"doc":"lustre/attribute","title":"cols","content":"pub fn cols(val: Int) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.cols\nlustre/attribute cols","url":"lustre/attribute.html#cols"},{"doc":"lustre/attribute","title":"controls","content":"pub fn controls(visible: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.controls\nlustre/attribute controls","url":"lustre/attribute.html#controls"},{"doc":"lustre/attribute","title":"disabled","content":"pub fn disabled(is_disabled: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.disabled\nlustre/attribute disabled","url":"lustre/attribute.html#disabled"},{"doc":"lustre/attribute","title":"download","content":"pub fn download(filename: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.download\nlustre/attribute download","url":"lustre/attribute.html#download"},{"doc":"lustre/attribute","title":"for","content":"pub fn for(id: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.for\nlustre/attribute for","url":"lustre/attribute.html#for"},{"doc":"lustre/attribute","title":"height","content":"pub fn height(val: Int) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.height\nlustre/attribute height","url":"lustre/attribute.html#height"},{"doc":"lustre/attribute","title":"href","content":"pub fn href(uri: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.href\nlustre/attribute href","url":"lustre/attribute.html#href"},{"doc":"lustre/attribute","title":"id","content":"pub fn id(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.id\nlustre/attribute id","url":"lustre/attribute.html#id"},{"doc":"lustre/attribute","title":"loop","content":"pub fn loop(should_loop: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.loop\nlustre/attribute loop","url":"lustre/attribute.html#loop"},{"doc":"lustre/attribute","title":"map","content":"pub fn map(attr: Attribute(a), f: fn(a) -&gt; b) -&gt; Attribute(b)\n\n \nSynonyms:\nlustre/attribute.map\nlustre/attribute map","url":"lustre/attribute.html#map"},{"doc":"lustre/attribute","title":"max","content":"pub fn max(val: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.max\nlustre/attribute max","url":"lustre/attribute.html#max"},{"doc":"lustre/attribute","title":"min","content":"pub fn min(val: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.min\nlustre/attribute min","url":"lustre/attribute.html#min"},{"doc":"lustre/attribute","title":"msg","content":"pub fn msg(uri: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.msg\nlustre/attribute msg","url":"lustre/attribute.html#msg"},{"doc":"lustre/attribute","title":"name","content":"pub fn name(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.name\nlustre/attribute name","url":"lustre/attribute.html#name"},{"doc":"lustre/attribute","title":"on","content":"pub fn on(name: String, handler: fn(Dynamic) -&gt; Option(a)) -&gt; Attribute(\n  a,\n)\n Attach custom event handlers to an element. A number of helper functions exist\n in this module to cover the most common events and use-cases, so you should\n check those out first.\n\n If you need to handle an event that isn&#39;t covered by the helper functions,\n then you can use `on` to attach a custom event handler. The callback is given\n the event object as a `Dynamic`.\n\n As a simple example, you can implement `on_click` like so:\n\n \n import gleam/option.{Some}\n import lustre/attribute.{Attribute}\n import lustre/event\n \n pub fn on_click(msg: msg) -&gt; Attribute(msg) {\n   use _ &lt;- event.on(&quot;click&quot;)\n   Some(msg)\n }\n \n\n By using `gleam/dynamic` you can decode the event object and pull out all sorts\n of useful data. This is how `on_input` is implemented:\n\n \n import gleam/dynamic\n import gleam/option.{None, Some}\n import gleam/result\n import lustre/attribute.{Attribute}\n import lustre/event\n \n pub fn on_input(msg: fn(String) -&gt; msg) -&gt; Attribute(msg) {\n   use event, dispatch &lt;- on(&quot;input&quot;)\n   let decode = dynamic.field(&quot;target&quot;, dynamic.field(&quot;value&quot;, dynamic.string))\n \n   case decode(event) {\n     Ok(value) -&gt; Some(msg(value))\n     Error(_) -&gt; None\n   }\n }\n \n\n You can take a look at the MDN reference for events\n [here](https://developer.mozilla.org/en-US/docs/Web/API/Event) to see what\n you can decode. \n\n Unlike the helpers in the rest of this module, it is possible to simply ignore\n the dispatch function and not dispatch a message at all. In fact, we saw this\n with the `on_input` example above: if we can&#39;t decode the event object, we\n simply return `None` and emit nothing.\n\n Beyond ignoring errors, this can be used to perform side effects we don&#39;t need\n to observe in our main application loop, such as logging...\n\n \n import gleam/io\n import gleam/option.{None}\n import lustre/attribute.{Attribute}\n import lustre/event\n \n pub fn log_on_click(msg: String) -&gt; Attribute(msg) {\n   use _ &lt;- event.on(&quot;click&quot;)\n   io.println(msg)\n   None\n }\n \n\nSynonyms:\nlustre/attribute.on\nlustre/attribute on","url":"lustre/attribute.html#on"},{"doc":"lustre/attribute","title":"pattern","content":"pub fn pattern(regex: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.pattern\nlustre/attribute pattern","url":"lustre/attribute.html#pattern"},{"doc":"lustre/attribute","title":"placeholder","content":"pub fn placeholder(text: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.placeholder\nlustre/attribute placeholder","url":"lustre/attribute.html#placeholder"},{"doc":"lustre/attribute","title":"property","content":"pub fn property(name: String, value: a) -&gt; Attribute(b)\n \nSynonyms:\nlustre/attribute.property\nlustre/attribute property","url":"lustre/attribute.html#property"},{"doc":"lustre/attribute","title":"readonly","content":"pub fn readonly(is_readonly: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.readonly\nlustre/attribute readonly","url":"lustre/attribute.html#readonly"},{"doc":"lustre/attribute","title":"rel","content":"pub fn rel(relationship: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.rel\nlustre/attribute rel","url":"lustre/attribute.html#rel"},{"doc":"lustre/attribute","title":"required","content":"pub fn required(is_required: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.required\nlustre/attribute required","url":"lustre/attribute.html#required"},{"doc":"lustre/attribute","title":"rows","content":"pub fn rows(val: Int) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.rows\nlustre/attribute rows","url":"lustre/attribute.html#rows"},{"doc":"lustre/attribute","title":"selected","content":"pub fn selected(is_selected: Bool) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.selected\nlustre/attribute selected","url":"lustre/attribute.html#selected"},{"doc":"lustre/attribute","title":"src","content":"pub fn src(uri: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.src\nlustre/attribute src","url":"lustre/attribute.html#src"},{"doc":"lustre/attribute","title":"step","content":"pub fn step(val: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.step\nlustre/attribute step","url":"lustre/attribute.html#step"},{"doc":"lustre/attribute","title":"style","content":"pub fn style(properties: List(#(String, String))) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.style\nlustre/attribute style","url":"lustre/attribute.html#style"},{"doc":"lustre/attribute","title":"target","content":"pub fn target(target: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.target\nlustre/attribute target","url":"lustre/attribute.html#target"},{"doc":"lustre/attribute","title":"to_string","content":"pub fn to_string(attr: Attribute(a)) -&gt; String\n\n \nSynonyms:\nlustre/attribute.to_string\nlustre/attribute to_string","url":"lustre/attribute.html#to_string"},{"doc":"lustre/attribute","title":"to_string_builder","content":"pub fn to_string_builder(attr: Attribute(a)) -&gt; StringBuilder\n\n\nSynonyms:\nlustre/attribute.to_string_builder\nlustre/attribute to_string_builder","url":"lustre/attribute.html#to_string_builder"},{"doc":"lustre/attribute","title":"type_","content":"pub fn type_(name: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.type_\nlustre/attribute type_","url":"lustre/attribute.html#type_"},{"doc":"lustre/attribute","title":"value","content":"pub fn value(val: Dynamic) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.value\nlustre/attribute value","url":"lustre/attribute.html#value"},{"doc":"lustre/attribute","title":"width","content":"pub fn width(val: Int) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.width\nlustre/attribute width","url":"lustre/attribute.html#width"},{"doc":"lustre/attribute","title":"wrap","content":"pub fn wrap(mode: String) -&gt; Attribute(a)\n\nSynonyms:\nlustre/attribute.wrap\nlustre/attribute wrap","url":"lustre/attribute.html#wrap"},{"doc":"lustre/attribute","title":"lustre/attribute","content":"","url":"lustre/attribute.html"},{"doc":"lustre/element","title":"Element","content":"pub opaque type Element(msg)\n\n \n\nSynonyms:\nlustre/element.Element\nlustre/element Element","url":"lustre/element.html#Element"},{"doc":"lustre/element","title":"h","content":"pub fn h(tag: String, attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n\n \nSynonyms:\nlustre/element.h\nlustre/element h","url":"lustre/element.html#h"},{"doc":"lustre/element","title":"map","content":"pub fn map(element: Element(a), f: fn(a) -&gt; b) -&gt; Element(b)\n\n \nSynonyms:\nlustre/element.map\nlustre/element map","url":"lustre/element.html#map"},{"doc":"lustre/element","title":"t","content":"pub fn t(content: String) -&gt; Element(a)\n\n \nSynonyms:\nlustre/element.t\nlustre/element t","url":"lustre/element.html#t"},{"doc":"lustre/element","title":"to_string","content":"pub fn to_string(element: Element(a)) -&gt; String\n\n \nSynonyms:\nlustre/element.to_string\nlustre/element to_string","url":"lustre/element.html#to_string"},{"doc":"lustre/element","title":"to_string_builder","content":"pub fn to_string_builder(element: Element(a)) -&gt; StringBuilder\n\n \nSynonyms:\nlustre/element.to_string_builder\nlustre/element to_string_builder","url":"lustre/element.html#to_string_builder"},{"doc":"lustre/element","title":"lustre/element","content":"","url":"lustre/element.html"},{"doc":"lustre/effect","title":"Effect","content":"pub opaque type Effect(action)\n A `Effect` represents some side effect we want the Lustre runtime to perform.\n It is parameterised by our app&#39;s `action` type because some effects need to\n get information back into your program.\n\n\nSynonyms:\nlustre/effect.Effect\nlustre/effect Effect","url":"lustre/effect.html#Effect"},{"doc":"lustre/effect","title":"batch","content":"pub fn batch(cmds: List(Effect(a))) -&gt; Effect(a)\n \n\nSynonyms:\nlustre/effect.batch\nlustre/effect batch","url":"lustre/effect.html#batch"},{"doc":"lustre/effect","title":"from","content":"pub fn from(effect: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Effect(a)\n Create a `Effect` from some custom side effect. This is mostly useful for \n package authors, or for integrating other libraries into your Lustre app.\n\n We pass in a function that recieves a `dispatch` callback that can be used\n to send messages to the Lustre runtime. We could, for example, create a `tick`\n command that uses the `setTimeout` JavaScript API to send a message to the\n runtime every second:\n\n \n import lustre/effect.{Effect}\n \n external fn set_interval(callback: fn() -&gt; any, interval: Int) =\n   &quot;&quot; &quot;window.setInterval&quot;\n \n pub fn every_second(msg: msg) -&gt; Effect(msg) {\n   use dispatch &lt;- effect.from\n \n   set_interval(fn() { dispatch(msg) }, 1000)\n }\n \n\nSynonyms:\nlustre/effect.from\nlustre/effect from","url":"lustre/effect.html#from"},{"doc":"lustre/effect","title":"map","content":"pub fn map(effect: Effect(a), f: fn(a) -&gt; b) -&gt; Effect(b)\n\nSynonyms:\nlustre/effect.map\nlustre/effect map","url":"lustre/effect.html#map"},{"doc":"lustre/effect","title":"none","content":"pub fn none() -&gt; Effect(a)\n Typically our app&#39;s `update` function needs to return a tuple of\n `#(model, Effect(action))`. When we don&#39;t need to perform any side effects we\n can just return `none()`!\n\nSynonyms:\nlustre/effect.none\nlustre/effect none","url":"lustre/effect.html#none"},{"doc":"lustre/effect","title":"lustre/effect","content":"","url":"lustre/effect.html"},{"doc":"lustre/event","title":"checked","content":"pub fn checked(event: Dynamic) -&gt; Result(Bool, List(DecodeError))\n A helpful decoder to extract the `checked` property from an event triggered\n by a checkbox.\n\nSynonyms:\nlustre/event.checked\nlustre/event checked","url":"lustre/event.html#checked"},{"doc":"lustre/event","title":"mouse_position","content":"pub fn mouse_position(event: Dynamic) -&gt; Result(\n  #(Float, Float),\n  List(DecodeError),\n)\n A helpful decoder to grab the mouse&#39;s current x and y position in the\n viewport from an event object.\n\nSynonyms:\nlustre/event.mouse_position\nlustre/event mouse_position","url":"lustre/event.html#mouse_position"},{"doc":"lustre/event","title":"on","content":"pub fn on(name: String, handler: fn(Dynamic) -&gt; Option(a)) -&gt; Attribute(\n  a,\n)\n\nSynonyms:\nlustre/event.on\nlustre/event on","url":"lustre/event.html#on"},{"doc":"lustre/event","title":"on_blur","content":"pub fn on_blur(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_blur\nlustre/event on_blur","url":"lustre/event.html#on_blur"},{"doc":"lustre/event","title":"on_check","content":"pub fn on_check(msg: fn(Bool) -&gt; a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_check\nlustre/event on_check","url":"lustre/event.html#on_check"},{"doc":"lustre/event","title":"on_click","content":"pub fn on_click(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_click\nlustre/event on_click","url":"lustre/event.html#on_click"},{"doc":"lustre/event","title":"on_focus","content":"pub fn on_focus(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_focus\nlustre/event on_focus","url":"lustre/event.html#on_focus"},{"doc":"lustre/event","title":"on_input","content":"pub fn on_input(msg: fn(String) -&gt; a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_input\nlustre/event on_input","url":"lustre/event.html#on_input"},{"doc":"lustre/event","title":"on_keydown","content":"pub fn on_keydown(msg: fn(String) -&gt; a) -&gt; Attribute(a)\n Listens for key dow events on an element, and dispatches a message with the\n current key being pressed.\n\nSynonyms:\nlustre/event.on_keydown\nlustre/event on_keydown","url":"lustre/event.html#on_keydown"},{"doc":"lustre/event","title":"on_keypress","content":"pub fn on_keypress(msg: fn(String) -&gt; a) -&gt; Attribute(a)\n Listens for key presses on an element, and dispatches a message with the\n current key being pressed.\n\nSynonyms:\nlustre/event.on_keypress\nlustre/event on_keypress","url":"lustre/event.html#on_keypress"},{"doc":"lustre/event","title":"on_keyup","content":"pub fn on_keyup(msg: fn(String) -&gt; a) -&gt; Attribute(a)\n Listens for key up events on an element, and dispatches a message with the\n current key being released.\n\nSynonyms:\nlustre/event.on_keyup\nlustre/event on_keyup","url":"lustre/event.html#on_keyup"},{"doc":"lustre/event","title":"on_mouse_down","content":"pub fn on_mouse_down(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_down\nlustre/event on_mouse_down","url":"lustre/event.html#on_mouse_down"},{"doc":"lustre/event","title":"on_mouse_enter","content":"pub fn on_mouse_enter(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_enter\nlustre/event on_mouse_enter","url":"lustre/event.html#on_mouse_enter"},{"doc":"lustre/event","title":"on_mouse_leave","content":"pub fn on_mouse_leave(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_leave\nlustre/event on_mouse_leave","url":"lustre/event.html#on_mouse_leave"},{"doc":"lustre/event","title":"on_mouse_out","content":"pub fn on_mouse_out(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_out\nlustre/event on_mouse_out","url":"lustre/event.html#on_mouse_out"},{"doc":"lustre/event","title":"on_mouse_over","content":"pub fn on_mouse_over(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_over\nlustre/event on_mouse_over","url":"lustre/event.html#on_mouse_over"},{"doc":"lustre/event","title":"on_mouse_up","content":"pub fn on_mouse_up(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_mouse_up\nlustre/event on_mouse_up","url":"lustre/event.html#on_mouse_up"},{"doc":"lustre/event","title":"on_submit","content":"pub fn on_submit(msg: a) -&gt; Attribute(a)\n\nSynonyms:\nlustre/event.on_submit\nlustre/event on_submit","url":"lustre/event.html#on_submit"},{"doc":"lustre/event","title":"value","content":"pub fn value(event: Dynamic) -&gt; Result(String, List(DecodeError))\n A helpful decoder to extract the `value` from an event object. This is handy\n for getting the value as a string from an input event, for example.\n\nSynonyms:\nlustre/event.value\nlustre/event value","url":"lustre/event.html#value"},{"doc":"lustre/event","title":"lustre/event","content":"","url":"lustre/event.html"},{"doc":"lustre","title":"App","content":"pub type App(model, msg)\n An `App` describes a Lustre application: what state it holds and what kind\n of actions get dispatched to update that model. The only useful thing you can\n do with an `App` is pass it to [`start`](#start).\n\n You can construct an `App` from the two constructors exposed in this module:\n [`basic`](#basic) and [`application`](#application). Although you can&#39;t do\n anything but [`start`](#start) them, the constructors are separated in case\n you want to set up an application but defer starting it until some later point\n in time.\n\n text\n                                          +--------+\n                                          |        |\n                                          | update |\n                                          |        |\n                                          +--------+\n                                            ^    |\n                                            |    | \n                                        Msg |    | #(Model, Effect(Msg))\n                                            |    |\n                                            |    v\n +------+                         +------------------------+\n |      |  #(Model, Effect(Msg))  |                        |\n | init |------------------------&gt;|     Lustre Runtime     |\n |      |                         |                        |\n +------+                         +------------------------+\n                                            ^    |\n                                            |    |\n                                        Msg |    | Model\n                                            |    |\n                                            |    v\n                                          +--------+\n                                          |        |\n                                          | render |\n                                          |        |\n                                          +--------+\n \n\n\nSynonyms:\nlustre.App\nlustre App","url":"lustre.html#App"},{"doc":"lustre","title":"Error","content":"pub type Error {\n  ElementNotFound\n  ComponentAlreadyRegistered\n}\n\nElementNotFound\n\n\nComponentAlreadyRegistered\n\n\nSynonyms:\nlustre.Error\nlustre Error","url":"lustre.html#Error"},{"doc":"lustre","title":"lustre","content":" Lustre is a declarative framework for building Web apps in Gleam. ","url":"lustre.html"},{"doc":"lustre/html","title":"a","content":"pub fn a(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Together with its href attribute, creates a hyperlink to web pages, files,\n email addresses, locations within the current page, or anything else a URL\n can address.\n \nSynonyms:\nlustre/html.a\nlustre/html a","url":"lustre/html.html#a"},{"doc":"lustre/html","title":"abbr","content":"pub fn abbr(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents an abbreviation or acronym.\n \nSynonyms:\nlustre/html.abbr\nlustre/html abbr","url":"lustre/html.html#abbr"},{"doc":"lustre/html","title":"address","content":"pub fn address(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Indicates that the enclosed HTML provides contact information for a person or\n people, or for an organization.\n \nSynonyms:\nlustre/html.address\nlustre/html address","url":"lustre/html.html#address"},{"doc":"lustre/html","title":"area","content":"pub fn area(attrs: List(Attribute(a))) -&gt; Element(a)\n Represents a word break opportunity—a position within text where the browser\n may optionally break a line, though its line-breaking rules would not\n otherwise create a break at that location.\n \nSynonyms:\nlustre/html.area\nlustre/html area","url":"lustre/html.html#area"},{"doc":"lustre/html","title":"article","content":"pub fn article(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents a self-contained composition in a document, page, application, or\n site, which is intended to be independently distributable or reusable (e.g.,\n in syndication). Examples include a forum post, a magazine or newspaper article,\n a blog entry, a product card, a user-submitted comment, an interactive widget\n or gadget, or any other independent item of content.\n \nSynonyms:\nlustre/html.article\nlustre/html article","url":"lustre/html.html#article"},{"doc":"lustre/html","title":"aside","content":"pub fn aside(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a portion of a document whose content is only indirectly related\n to the document&#39;s main content. Asides are frequently presented as sidebars\n or call-out boxes.\n \nSynonyms:\nlustre/html.aside\nlustre/html aside","url":"lustre/html.html#aside"},{"doc":"lustre/html","title":"audio","content":"pub fn audio(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Defines an area inside an image map that has predefined clickable areas. An\n image map allows geometric areas on an image to be associated with hyperlink.\n \nSynonyms:\nlustre/html.audio\nlustre/html audio","url":"lustre/html.html#audio"},{"doc":"lustre/html","title":"b","content":"pub fn b(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Used to draw the reader&#39;s attention to the element&#39;s contents, which are not\n otherwise granted special importance. This was formerly known as the Boldface\n element, and most browsers still draw the text in boldface. However, you\n should not use &lt;b&gt; for styling text or granting importance. If you wish to\n create boldface text, you should use the CSS font-weight property. If you\n wish to indicate an element is of special importance, you should use the\n strong element.\n \nSynonyms:\nlustre/html.b\nlustre/html b","url":"lustre/html.html#b"},{"doc":"lustre/html","title":"base","content":"pub fn base(attrs: List(Attribute(a))) -&gt; Element(a)\n Specifies the base URL to use for all relative URLs in a document. There can\n be only one such element in a document.\n \nSynonyms:\nlustre/html.base\nlustre/html base","url":"lustre/html.html#base"},{"doc":"lustre/html","title":"bdi","content":"pub fn bdi(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Tells the browser&#39;s bidirectional algorithm to treat the text it contains in\n isolation from its surrounding text. It&#39;s particularly useful when a website\n dynamically inserts some text and doesn&#39;t know the directionality of the\n text being inserted.\n \nSynonyms:\nlustre/html.bdi\nlustre/html bdi","url":"lustre/html.html#bdi"},{"doc":"lustre/html","title":"bdo","content":"pub fn bdo(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Overrides the current directionality of text, so that the text within is\n rendered in a different direction.\n \nSynonyms:\nlustre/html.bdo\nlustre/html bdo","url":"lustre/html.html#bdo"},{"doc":"lustre/html","title":"blockquote","content":"pub fn blockquote(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Indicates that the enclosed text is an extended quotation. Usually, this is\n rendered visually by indentation. A URL for the source of the quotation may\n be given using the cite attribute, while a text representation of the source\n can be given using the &lt;cite&gt; element.\n \nSynonyms:\nlustre/html.blockquote\nlustre/html blockquote","url":"lustre/html.html#blockquote"},{"doc":"lustre/html","title":"body","content":"pub fn body(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents the content of an HTML document. There can be only one such element\n in a document.\n \nSynonyms:\nlustre/html.body\nlustre/html body","url":"lustre/html.html#body"},{"doc":"lustre/html","title":"br","content":"pub fn br(attrs: List(Attribute(a))) -&gt; Element(a)\n Produces a line break in text (carriage-return). It is useful for writing a\n poem or an address, where the division of lines is significant.\n \nSynonyms:\nlustre/html.br\nlustre/html br","url":"lustre/html.html#br"},{"doc":"lustre/html","title":"button","content":"pub fn button(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n An interactive element activated by a user with a mouse, keyboard, finger,\n voice command, or other assistive technology. Once activated, it performs an\n action, such as submitting a form or opening a dialog.\n \nSynonyms:\nlustre/html.button\nlustre/html button","url":"lustre/html.html#button"},{"doc":"lustre/html","title":"canvas","content":"pub fn canvas(attrs: List(Attribute(a))) -&gt; Element(a)\n Container element to use with either the canvas scripting API or the WebGL\n API to draw graphics and animations.\n \nSynonyms:\nlustre/html.canvas\nlustre/html canvas","url":"lustre/html.html#canvas"},{"doc":"lustre/html","title":"caption","content":"pub fn caption(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Specifies the caption (or title) of a table.\n \nSynonyms:\nlustre/html.caption\nlustre/html caption","url":"lustre/html.html#caption"},{"doc":"lustre/html","title":"cite","content":"pub fn cite(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Used to mark up the title of a cited creative work. The reference may be in\n an abbreviated form according to context-appropriate conventions related to\n citation metadata.\n \nSynonyms:\nlustre/html.cite\nlustre/html cite","url":"lustre/html.html#cite"},{"doc":"lustre/html","title":"code","content":"pub fn code(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Displays its contents styled in a fashion intended to indicate that the text\n is a short fragment of computer code. By default, the content text is\n displayed using the user agent&#39;s default monospace font.\n \nSynonyms:\nlustre/html.code\nlustre/html code","url":"lustre/html.html#code"},{"doc":"lustre/html","title":"col","content":"pub fn col(attrs: List(Attribute(a))) -&gt; Element(a)\n Defines a column within a table and is used for defining common semantics on\n all common cells. It is generally found within a &lt;colgroup&gt; element.\n \nSynonyms:\nlustre/html.col\nlustre/html col","url":"lustre/html.html#col"},{"doc":"lustre/html","title":"colgroup","content":"pub fn colgroup(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Defines a group of columns within a table.\n \nSynonyms:\nlustre/html.colgroup\nlustre/html colgroup","url":"lustre/html.html#colgroup"},{"doc":"lustre/html","title":"data","content":"pub fn data(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Links a given piece of content with a machine-readable translation. If the\n content is time- or date-related, the&lt;time&gt; element must be used.\n \nSynonyms:\nlustre/html.data\nlustre/html data","url":"lustre/html.html#data"},{"doc":"lustre/html","title":"datalist","content":"pub fn datalist(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Contains a set of &lt;option&gt; elements that represent the permissible or\n recommended options available to choose from within other controls.\n \nSynonyms:\nlustre/html.datalist\nlustre/html datalist","url":"lustre/html.html#datalist"},{"doc":"lustre/html","title":"dd","content":"pub fn dd(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Provides the description, definition, or value for the preceding term (&lt;dt&gt;)\n in a description list (&lt;dl&gt;).\n \nSynonyms:\nlustre/html.dd\nlustre/html dd","url":"lustre/html.html#dd"},{"doc":"lustre/html","title":"del","content":"pub fn del(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a range of text that has been deleted from a document. This can\n be used when rendering &quot;track changes&quot; or source code diff information, for\n example. The &lt;ins&gt; element can be used for the opposite purpose: to indicate\n text that has been added to the document.\n \nSynonyms:\nlustre/html.del\nlustre/html del","url":"lustre/html.html#del"},{"doc":"lustre/html","title":"details","content":"pub fn details(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Creates a disclosure widget in which information is visible only when the\n widget is toggled into an &quot;open&quot; state. A summary or label must be provided\n using the &lt;summary&gt; element.\n \nSynonyms:\nlustre/html.details\nlustre/html details","url":"lustre/html.html#details"},{"doc":"lustre/html","title":"dfn","content":"pub fn dfn(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Used to indicate the term being defined within the context of a definition\n phrase or sentence. The ancestor &lt;p&gt; element, the &lt;dt&gt;/&lt;dd&gt; pairing, or the\n nearest section ancestor of the &lt;dfn&gt; element, is considered to be the\n definition of the term.\n \nSynonyms:\nlustre/html.dfn\nlustre/html dfn","url":"lustre/html.html#dfn"},{"doc":"lustre/html","title":"dialog","content":"pub fn dialog(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents a dialog box or other interactive component, such as a dismissible\n alert, inspector, or subwindow.\n \nSynonyms:\nlustre/html.dialog\nlustre/html dialog","url":"lustre/html.html#dialog"},{"doc":"lustre/html","title":"div","content":"pub fn div(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n The generic container for flow content. It has no effect on the content or\n layout until styled in some way using CSS (e.g., styling is directly applied\n to it, or some kind of layout model like flexbox is applied to its parent\n element).\n \nSynonyms:\nlustre/html.div\nlustre/html div","url":"lustre/html.html#div"},{"doc":"lustre/html","title":"dl","content":"pub fn dl(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a description list. The element encloses a list of groups of terms\n (specified using the &lt;dt&gt; element) and descriptions (provided by &lt;dd&gt; elements).\n Common uses for this element are to implement a glossary or to display metadata\n (a list of key-value pairs).\n \nSynonyms:\nlustre/html.dl\nlustre/html dl","url":"lustre/html.html#dl"},{"doc":"lustre/html","title":"dt","content":"pub fn dt(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Specifies a term in a description or definition list, and as such must be\n used inside a &lt;dl&gt; element. It is usually followed by a &lt;dd&gt; element;\n however, multiple &lt;dt&gt; elements in a row indicate several terms that are\n all defined by the immediate next &lt;dd&gt; element.\n \nSynonyms:\nlustre/html.dt\nlustre/html dt","url":"lustre/html.html#dt"},{"doc":"lustre/html","title":"em","content":"pub fn em(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Marks text that has stress emphasis. The &lt;em&gt; element can be nested, with\n each nesting level indicating a greater degree of emphasis.\n \nSynonyms:\nlustre/html.em\nlustre/html em","url":"lustre/html.html#em"},{"doc":"lustre/html","title":"embed","content":"pub fn embed(attrs: List(Attribute(a))) -&gt; Element(a)\n Embeds external content at the specified point in the document. This content \nis provided by an external application or other source of interactive content\n such as a browser plug-in.\n \nSynonyms:\nlustre/html.embed\nlustre/html embed","url":"lustre/html.html#embed"},{"doc":"lustre/html","title":"fieldset","content":"pub fn fieldset(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Used to group several controls as well as labels (&lt;label&gt;) within a web form.\n \nSynonyms:\nlustre/html.fieldset\nlustre/html fieldset","url":"lustre/html.html#fieldset"},{"doc":"lustre/html","title":"figcaption","content":"pub fn figcaption(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents a caption or legend describing the rest of the contents of its\n parent &lt;figure&gt; element.\n \nSynonyms:\nlustre/html.figcaption\nlustre/html figcaption","url":"lustre/html.html#figcaption"},{"doc":"lustre/html","title":"figure","content":"pub fn figure(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents self-contained content, potentially with an optional caption,\n which is specified using the &lt;figcaption&gt; element. The figure, its caption,\n and its contents are referenced as a single unit.\n \nSynonyms:\nlustre/html.figure\nlustre/html figure","url":"lustre/html.html#figure"},{"doc":"lustre/html","title":"footer","content":"pub fn footer(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents a footer for its nearest ancestor sectioning content or sectioning\n root element. A &lt;footer&gt; typically contains information about the author of\n the section, copyright data, or links to related documents.\n \nSynonyms:\nlustre/html.footer\nlustre/html footer","url":"lustre/html.html#footer"},{"doc":"lustre/html","title":"form","content":"pub fn form(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a document section containing interactive controls for submitting\n information.\n \nSynonyms:\nlustre/html.form\nlustre/html form","url":"lustre/html.html#form"},{"doc":"lustre/html","title":"h1","content":"pub fn h1(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represent six levels of section headings. &lt;h1&gt; is the highest section level\n and &lt;h6&gt; is the lowest.\n \nSynonyms:\nlustre/html.h1\nlustre/html h1","url":"lustre/html.html#h1"},{"doc":"lustre/html","title":"h2","content":"pub fn h2(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represent six levels of section headings. &lt;h1&gt; is the highest section level\n and &lt;h6&gt; is the lowest.\n \nSynonyms:\nlustre/html.h2\nlustre/html h2","url":"lustre/html.html#h2"},{"doc":"lustre/html","title":"h3","content":"pub fn h3(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represent six levels of section headings. &lt;h1&gt; is the highest section level\n and &lt;h6&gt; is the lowest.\n \nSynonyms:\nlustre/html.h3\nlustre/html h3","url":"lustre/html.html#h3"},{"doc":"lustre/html","title":"h4","content":"pub fn h4(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represent six levels of section headings. &lt;h1&gt; is the highest section level\n and &lt;h6&gt; is the lowest.\n \nSynonyms:\nlustre/html.h4\nlustre/html h4","url":"lustre/html.html#h4"},{"doc":"lustre/html","title":"h5","content":"pub fn h5(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represent six levels of section headings. &lt;h1&gt; is the highest section level\n and &lt;h6&gt; is the lowest.\n \nSynonyms:\nlustre/html.h5\nlustre/html h5","url":"lustre/html.html#h5"},{"doc":"lustre/html","title":"h6","content":"pub fn h6(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represent six levels of section headings. &lt;h1&gt; is the highest section level\n and &lt;h6&gt; is the lowest.\n \nSynonyms:\nlustre/html.h6\nlustre/html h6","url":"lustre/html.html#h6"},{"doc":"lustre/html","title":"head","content":"pub fn head(attrs: List(Attribute(a))) -&gt; Element(a)\n Contains machine-readable information (metadata) about the document, like its\n title, scripts, and style sheets.\n \nSynonyms:\nlustre/html.head\nlustre/html head","url":"lustre/html.html#head"},{"doc":"lustre/html","title":"header","content":"pub fn header(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents introductory content, typically a group of introductory or navigational\n aids. It may contain some heading elements but also a logo, a search form, an\n author name, and other elements.\n \nSynonyms:\nlustre/html.header\nlustre/html header","url":"lustre/html.html#header"},{"doc":"lustre/html","title":"hgroup","content":"pub fn hgroup(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents a heading grouped with any secondary content, such as subheadings,\n an alternative title, or a tagline.\n \nSynonyms:\nlustre/html.hgroup\nlustre/html hgroup","url":"lustre/html.html#hgroup"},{"doc":"lustre/html","title":"hr","content":"pub fn hr(attrs: List(Attribute(a))) -&gt; Element(a)\n Represents a thematic break between paragraph-level elements: for example,\n a change of scene in a story, or a shift of topic within a section.\n \nSynonyms:\nlustre/html.hr\nlustre/html hr","url":"lustre/html.html#hr"},{"doc":"lustre/html","title":"html","content":"pub fn html(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents the root (top-level element) of an HTML document, so it is also\n referred to as the root element. All other elements must be descendants of\n this element.\n \nSynonyms:\nlustre/html.html\nlustre/html html","url":"lustre/html.html#html"},{"doc":"lustre/html","title":"i","content":"pub fn i(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a range of text that is set off from the normal text for some\n reason, such as idiomatic text, technical terms, and taxonomical designations,\n among others. Historically, these have been presented using italicized type,\n which is the original source of the &lt;i&gt; naming of this element.\n \nSynonyms:\nlustre/html.i\nlustre/html i","url":"lustre/html.html#i"},{"doc":"lustre/html","title":"iframe","content":"pub fn iframe(attrs: List(Attribute(a))) -&gt; Element(a)\n Represents a nested browsing context, embedding another HTML page into the\n current one.\n \nSynonyms:\nlustre/html.iframe\nlustre/html iframe","url":"lustre/html.html#iframe"},{"doc":"lustre/html","title":"img","content":"pub fn img(attrs: List(Attribute(a))) -&gt; Element(a)\n Used to embed sound content in documents. It may contain one or more audio\n sources, represented using the src attribute or the source element: the\n browser will choose the most suitable one. It can also be the destination\n for streamed media, using a MediaStream.\n \nSynonyms:\nlustre/html.img\nlustre/html img","url":"lustre/html.html#img"},{"doc":"lustre/html","title":"input","content":"pub fn input(attrs: List(Attribute(a))) -&gt; Element(a)\n Used to create interactive controls for web-based forms to accept data from \n he user; a wide variety of types of input data and control widgets are\n available, depending on the device and user agent. The &lt;input&gt; element is\n one of the most powerful and complex in all of HTML due to the sheer number\n of combinations of input types and attributes.\n \nSynonyms:\nlustre/html.input\nlustre/html input","url":"lustre/html.html#input"},{"doc":"lustre/html","title":"ins","content":"pub fn ins(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a range of text that has been added to a document. You can use the\n &lt;del&gt; element to similarly represent a range of text that has been deleted\n from the document.\n \nSynonyms:\nlustre/html.ins\nlustre/html ins","url":"lustre/html.html#ins"},{"doc":"lustre/html","title":"kbd","content":"pub fn kbd(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a span of inline text denoting textual user input from a keyboard,\n voice input, or any other text entry device. By convention, the user agent \n defaults to rendering the contents of a &lt;kbd&gt; element using its default\n monospace font, although this is not mandated by the HTML standard.\n \nSynonyms:\nlustre/html.kbd\nlustre/html kbd","url":"lustre/html.html#kbd"},{"doc":"lustre/html","title":"label","content":"pub fn label(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a caption for an item in a user interface.\n \nSynonyms:\nlustre/html.label\nlustre/html label","url":"lustre/html.html#label"},{"doc":"lustre/html","title":"legend","content":"pub fn legend(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents a caption for the content of its parent &lt;fieldset&gt;.\n \nSynonyms:\nlustre/html.legend\nlustre/html legend","url":"lustre/html.html#legend"},{"doc":"lustre/html","title":"li","content":"pub fn li(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents an item in a list. It must be contained in a parent element: an\n ordered list (&lt;ol&gt;), an unordered list (&lt;ul&gt;), or a menu (&lt;menu&gt;). In menus\n and unordered lists, list items are usually displayed using bullet points.\n In ordered lists, they are usually displayed with an ascending counter on\n the left, such as a number or letter.\n \nSynonyms:\nlustre/html.li\nlustre/html li","url":"lustre/html.html#li"},{"doc":"lustre/html","title":"link","content":"pub fn link(attrs: List(Attribute(a))) -&gt; Element(a)\n Specifies relationships between the current document and an external resource.\n This element is most commonly used to link to CSS but is also used to establish\n site icons (both &quot;favicon&quot; style icons and icons for the home screen and apps\n on mobile devices) among other things.\n \nSynonyms:\nlustre/html.link\nlustre/html link","url":"lustre/html.html#link"},{"doc":"lustre/html","title":"main","content":"pub fn main(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents the dominant content of the body of a document. The main content\n area consists of content that is directly related to or expands upon the\n central topic of a document, or the central functionality of an application.\n \nSynonyms:\nlustre/html.main\nlustre/html main","url":"lustre/html.html#main"},{"doc":"lustre/html","title":"map","content":"pub fn map(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Used with &lt;area&gt; elements to define an image map (a clickable link area).\n \nSynonyms:\nlustre/html.map\nlustre/html map","url":"lustre/html.html#map"},{"doc":"lustre/html","title":"mark","content":"pub fn mark(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents text which is marked or highlighted for reference or notation\n purposes due to the marked passage&#39;s relevance in the enclosing context.\n \nSynonyms:\nlustre/html.mark\nlustre/html mark","url":"lustre/html.html#mark"},{"doc":"lustre/html","title":"math","content":"pub fn math(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n The top-level element in MathML. Every valid MathML instance must be wrapped\n in it. In addition, you must not nest a second &lt;math&gt; element in another,\n but you can have an arbitrary number of other child elements in it.\n \nSynonyms:\nlustre/html.math\nlustre/html math","url":"lustre/html.html#math"},{"doc":"lustre/html","title":"menu","content":"pub fn menu(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n A semantic alternative to &lt;ul&gt;, but treated by browsers (and exposed through\n the accessibility tree) as no different than &lt;ul&gt;. It represents an unordered\n list of items (which are represented by &lt;li&gt; elements).\n \nSynonyms:\nlustre/html.menu\nlustre/html menu","url":"lustre/html.html#menu"},{"doc":"lustre/html","title":"meta","content":"pub fn meta(attrs: List(Attribute(a))) -&gt; Element(a)\n Represents metadata that cannot be represented by other HTML meta-related\n elements, like &lt;base&gt;, &lt;link&gt;, &lt;script&gt;, &lt;style&gt; and &lt;title&gt;.\n \nSynonyms:\nlustre/html.meta\nlustre/html meta","url":"lustre/html.html#meta"},{"doc":"lustre/html","title":"meter","content":"pub fn meter(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents either a scalar value within a known range or a fractional value.\n \nSynonyms:\nlustre/html.meter\nlustre/html meter","url":"lustre/html.html#meter"},{"doc":"lustre/html","title":"nav","content":"pub fn nav(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a section of a page whose purpose is to provide navigation links,\n either within the current document or to other documents. Common examples of\n navigation sections are menus, tables of contents, and indexes.\n \nSynonyms:\nlustre/html.nav\nlustre/html nav","url":"lustre/html.html#nav"},{"doc":"lustre/html","title":"noscript","content":"pub fn noscript(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Defines a section of HTML to be inserted if a script type on the page is\n unsupported or if scripting is currently turned off in the browser.\n \nSynonyms:\nlustre/html.noscript\nlustre/html noscript","url":"lustre/html.html#noscript"},{"doc":"lustre/html","title":"object","content":"pub fn object(attrs: List(Attribute(a))) -&gt; Element(a)\n Represents an external resource, which can be treated as an image, a nested\n browsing context, or a resource to be handled by a plugin.\n \nSynonyms:\nlustre/html.object\nlustre/html object","url":"lustre/html.html#object"},{"doc":"lustre/html","title":"ol","content":"pub fn ol(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents an ordered list of items — typically rendered as a numbered list.\n\nSynonyms:\nlustre/html.ol\nlustre/html ol","url":"lustre/html.html#ol"},{"doc":"lustre/html","title":"optgroup","content":"pub fn optgroup(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Creates a grouping of options within a &lt;select&gt; element.\n \nSynonyms:\nlustre/html.optgroup\nlustre/html optgroup","url":"lustre/html.html#optgroup"},{"doc":"lustre/html","title":"option","content":"pub fn option(attrs: List(Attribute(a))) -&gt; Element(a)\n Used to define an item contained in a select, an &lt;optgroup&gt;, or a &lt;datalist&gt;\n element. As such, &lt;option&gt; can represent menu items in popups and other lists\n of items in an HTML document.\n \nSynonyms:\nlustre/html.option\nlustre/html option","url":"lustre/html.html#option"},{"doc":"lustre/html","title":"output","content":"pub fn output(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Container element into which a site or app can inject the results of a\n calculation or the outcome of a user action.\n \nSynonyms:\nlustre/html.output\nlustre/html output","url":"lustre/html.html#output"},{"doc":"lustre/html","title":"p","content":"pub fn p(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a paragraph. Paragraphs are usually represented in visual media\n as blocks of text separated from adjacent blocks by blank lines and/or\n first-line indentation, but HTML paragraphs can be any structural grouping\n of related content, such as images or form fields.\n \nSynonyms:\nlustre/html.p\nlustre/html p","url":"lustre/html.html#p"},{"doc":"lustre/html","title":"picture","content":"pub fn picture(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Contains zero or more &lt;source&gt; elements and one &lt;img&gt; element to offer\n alternative versions of an image for different display/device scenarios.\n \nSynonyms:\nlustre/html.picture\nlustre/html picture","url":"lustre/html.html#picture"},{"doc":"lustre/html","title":"portal","content":"pub fn portal(attrs: List(Attribute(a))) -&gt; Element(a)\n Enables the embedding of another HTML page into the current one to enable\n smoother navigation into new pages.\n \nSynonyms:\nlustre/html.portal\nlustre/html portal","url":"lustre/html.html#portal"},{"doc":"lustre/html","title":"pre","content":"pub fn pre(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents preformatted text which is to be presented exactly as written in\n the HTML file. The text is typically rendered using a non-proportional, or\n monospaced, font. Whitespace inside this element is displayed as written.\n \nSynonyms:\nlustre/html.pre\nlustre/html pre","url":"lustre/html.html#pre"},{"doc":"lustre/html","title":"progress","content":"pub fn progress(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Displays an indicator showing the completion progress of a task, typically\n displayed as a progress bar.\n \nSynonyms:\nlustre/html.progress\nlustre/html progress","url":"lustre/html.html#progress"},{"doc":"lustre/html","title":"q","content":"pub fn q(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Indicates that the enclosed text is a short inline quotation. Most modern\n browsers implement this by surrounding the text in quotation marks. This\n element is intended for short quotations that don&#39;t require paragraph\n breaks; for long quotations use the &lt;blockquote&gt; element.\n \nSynonyms:\nlustre/html.q\nlustre/html q","url":"lustre/html.html#q"},{"doc":"lustre/html","title":"rp","content":"pub fn rp(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Used to provide fall-back parentheses for browsers that do not support the\n display of ruby annotations using the &lt;ruby&gt; element. One &lt;rp&gt; element\n should enclose each of the opening and closing parentheses that wrap the\n &lt;rt&gt; element that contains the annotation&#39;s text.\n \nSynonyms:\nlustre/html.rp\nlustre/html rp","url":"lustre/html.html#rp"},{"doc":"lustre/html","title":"rt","content":"pub fn rt(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Specifies the ruby text component of a ruby annotation, which is used to\n provide pronunciation, translation, or transliteration information for East\n Asian typography. The &lt;rt&gt; element must always be contained within a &lt;ruby&gt; \n element.\n \nSynonyms:\nlustre/html.rt\nlustre/html rt","url":"lustre/html.html#rt"},{"doc":"lustre/html","title":"ruby","content":"pub fn ruby(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents small annotations that are rendered above, below, or next to base\n text, usually used for showing the pronunciation of East Asian characters.\n It can also be used for annotating other kinds of text, but this usage is\n less common.\n \nSynonyms:\nlustre/html.ruby\nlustre/html ruby","url":"lustre/html.html#ruby"},{"doc":"lustre/html","title":"s","content":"pub fn s(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Renders text with a strikethrough, or a line through it. Use the &lt;s&gt; element\n to represent things that are no longer relevant or no longer accurate.\n However, &lt;s&gt; is not appropriate when indicating document edits; for that,\n use the del and ins elements, as appropriate.\n \nSynonyms:\nlustre/html.s\nlustre/html s","url":"lustre/html.html#s"},{"doc":"lustre/html","title":"samp","content":"pub fn samp(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Used to enclose inline text which represents sample (or quoted) output from\n a computer program. Its contents are typically rendered using the browser&#39;s\n default monospaced font (such as Courier or Lucida Console).\n \nSynonyms:\nlustre/html.samp\nlustre/html samp","url":"lustre/html.html#samp"},{"doc":"lustre/html","title":"script","content":"pub fn script(attrs: List(Attribute(a)), js: String) -&gt; Element(a)\n Used to embed executable code or data; this is typically used to embed or\n refer to JavaScript code. The &lt;script&gt; element can also be used with other\n languages, such as WebGL&#39;s GLSL shader programming language and JSON.\n \nSynonyms:\nlustre/html.script\nlustre/html script","url":"lustre/html.html#script"},{"doc":"lustre/html","title":"search","content":"pub fn search(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents a part that contains a set of form controls or other content related\n to performing a search or filtering operation.\n \nSynonyms:\nlustre/html.search\nlustre/html search","url":"lustre/html.html#search"},{"doc":"lustre/html","title":"section","content":"pub fn section(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents a generic standalone section of a document, which doesn&#39;t have a\n more specific semantic element to represent it. Sections should always have\n a heading, with very few exceptions.\n \nSynonyms:\nlustre/html.section\nlustre/html section","url":"lustre/html.html#section"},{"doc":"lustre/html","title":"select","content":"pub fn select(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Represents a control that provides a menu of options.\n \nSynonyms:\nlustre/html.select\nlustre/html select","url":"lustre/html.html#select"},{"doc":"lustre/html","title":"slot","content":"pub fn slot(attrs: List(Attribute(a))) -&gt; Element(a)\n Part of the Web Components technology suite, this element is a placeholder\n inside a web component that you can fill with your own markup, which lets you\n create separate DOM trees and present them together.\n\nSynonyms:\nlustre/html.slot\nlustre/html slot","url":"lustre/html.html#slot"},{"doc":"lustre/html","title":"small","content":"pub fn small(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents side-comments and small print, like copyright and legal text,\n independent of its styled presentation. By default, it renders text within\n it one font size smaller, such as from small to x-small.\n \nSynonyms:\nlustre/html.small\nlustre/html small","url":"lustre/html.html#small"},{"doc":"lustre/html","title":"source","content":"pub fn source(attrs: List(Attribute(a))) -&gt; Element(a)\n Specifies multiple media resources for the picture, the audio element, or\n the video element. It is a void element, meaning that it has no content and\n does not have a closing tag. It is commonly used to offer the same media\n content in multiple file formats in order to provide compatibility with a\n broad range of browsers given their differing support for image file formats\n and media file formats.\n \nSynonyms:\nlustre/html.source\nlustre/html source","url":"lustre/html.html#source"},{"doc":"lustre/html","title":"span","content":"pub fn span(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n A generic inline container for phrasing content, which does not inherently\n represent anything. It can be used to group elements for styling purposes\n (using the class or id attributes), or because they share attribute values,\n such as lang. It should be used only when no other semantic element is\n appropriate. &lt;span&gt; is very much like a div element, but div is a block-level\n element whereas a &lt;span&gt; is an inline-level element.\n \nSynonyms:\nlustre/html.span\nlustre/html span","url":"lustre/html.html#span"},{"doc":"lustre/html","title":"strong","content":"pub fn strong(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Indicates that its contents have strong importance, seriousness, or urgency.\n Browsers typically render the contents in bold type.\n \nSynonyms:\nlustre/html.strong\nlustre/html strong","url":"lustre/html.html#strong"},{"doc":"lustre/html","title":"style","content":"pub fn style(attrs: List(Attribute(a)), css: String) -&gt; Element(a)\n Contains style information for a document or part of a document. It contains\n CSS, which is applied to the contents of the document containing this element.\n \nSynonyms:\nlustre/html.style\nlustre/html style","url":"lustre/html.html#style"},{"doc":"lustre/html","title":"sub","content":"pub fn sub(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Specifies inline text which should be displayed as subscript for solely\n typographical reasons. Subscripts are typically rendered with a lowered\n baseline using smaller text.\n \nSynonyms:\nlustre/html.sub\nlustre/html sub","url":"lustre/html.html#sub"},{"doc":"lustre/html","title":"summary","content":"pub fn summary(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n Specifies a summary, caption, or legend for a details element&#39;s disclosure box.\n Clicking the &lt;summary&gt; element toggles the state of the parent &lt;details&gt; element\n open and closed.\n \nSynonyms:\nlustre/html.summary\nlustre/html summary","url":"lustre/html.html#summary"},{"doc":"lustre/html","title":"sup","content":"pub fn sup(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Specifies inline text which is to be displayed as superscript for solely\n typographical reasons. Superscripts are usually rendered with a raised\n baseline using smaller text.\n \nSynonyms:\nlustre/html.sup\nlustre/html sup","url":"lustre/html.html#sup"},{"doc":"lustre/html","title":"svg","content":"pub fn svg(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Container defining a new coordinate system and viewport. It is used as the\n outermost element of SVG documents, but it can also be used to embed an SVG\n fragment inside an SVG or HTML document.\n \nSynonyms:\nlustre/html.svg\nlustre/html svg","url":"lustre/html.html#svg"},{"doc":"lustre/html","title":"table","content":"pub fn table(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents tabular data — that is, information presented in a two-dimensional\n table comprised of rows and columns of cells containing data.\n \nSynonyms:\nlustre/html.table\nlustre/html table","url":"lustre/html.html#table"},{"doc":"lustre/html","title":"tbody","content":"pub fn tbody(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Encapsulates a set of table rows (&lt;tr&gt; elements), indicating that they\n comprise the body of the table (&lt;table&gt;).\n \nSynonyms:\nlustre/html.tbody\nlustre/html tbody","url":"lustre/html.html#tbody"},{"doc":"lustre/html","title":"td","content":"pub fn td(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Defines a cell of a table that contains data. It participates in the table\n model.\n \nSynonyms:\nlustre/html.td\nlustre/html td","url":"lustre/html.html#td"},{"doc":"lustre/html","title":"template","content":"pub fn template(attrs: List(Attribute(a)), children: List(\n    Element(a),\n  )) -&gt; Element(a)\n A mechanism for holding HTML that is not to be rendered immediately when a\n page is loaded but may be instantiated subsequently during runtime using\n JavaScript.\n \nSynonyms:\nlustre/html.template\nlustre/html template","url":"lustre/html.html#template"},{"doc":"lustre/html","title":"textarea","content":"pub fn textarea(attrs: List(Attribute(a))) -&gt; Element(a)\n Represents a multi-line plain-text editing control, useful when you want to\n allow users to enter a sizeable amount of free-form text, for example, a \n comment on a review or feedback form.\n \nSynonyms:\nlustre/html.textarea\nlustre/html textarea","url":"lustre/html.html#textarea"},{"doc":"lustre/html","title":"tfoot","content":"pub fn tfoot(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Defines a set of rows summarizing the columns of the table.\n \nSynonyms:\nlustre/html.tfoot\nlustre/html tfoot","url":"lustre/html.html#tfoot"},{"doc":"lustre/html","title":"th","content":"pub fn th(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Defines a cell as a header of a group of table cells. The exact nature of\n this group is defined by the scope and headers attributes.\n \nSynonyms:\nlustre/html.th\nlustre/html th","url":"lustre/html.html#th"},{"doc":"lustre/html","title":"thead","content":"pub fn thead(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Defines a set of rows defining the head of the columns of the table.\n \nSynonyms:\nlustre/html.thead\nlustre/html thead","url":"lustre/html.html#thead"},{"doc":"lustre/html","title":"time","content":"pub fn time(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a specific period in time. It may include the datetime attribute\n to translate dates into machine-readable format, allowing for better search\n engine results or custom features such as reminders.\n \nSynonyms:\nlustre/html.time\nlustre/html time","url":"lustre/html.html#time"},{"doc":"lustre/html","title":"title","content":"pub fn title(attrs: List(Attribute(a)), text: String) -&gt; Element(\n  a,\n)\n Defines the document&#39;s title that is shown in a browser&#39;s title bar or a\n page&#39;s tab. It only contains text; tags within the element are ignored.\n \nSynonyms:\nlustre/html.title\nlustre/html title","url":"lustre/html.html#title"},{"doc":"lustre/html","title":"tr","content":"pub fn tr(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Defines a row of cells in a table. The row&#39;s cells can then be established\n using a mix of &lt;td&gt; (data cell) and &lt;th&gt; (header cell) elements.\n \nSynonyms:\nlustre/html.tr\nlustre/html tr","url":"lustre/html.html#tr"},{"doc":"lustre/html","title":"track","content":"pub fn track(attrs: List(Attribute(a))) -&gt; Element(a)\n Used as a child of the media elements, audio and video. It lets you specify\n timed text tracks (or time-based data), for example to automatically handle\n subtitles. The tracks are formatted in WebVTT format (.vtt files)—Web Video\n Text Tracks.\n \nSynonyms:\nlustre/html.track\nlustre/html track","url":"lustre/html.html#track"},{"doc":"lustre/html","title":"u","content":"pub fn u(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents a span of inline text which should be rendered in a way that\n indicates that it has a non-textual annotation. This is rendered by default\n as a simple solid underline but may be altered using CSS.\n \nSynonyms:\nlustre/html.u\nlustre/html u","url":"lustre/html.html#u"},{"doc":"lustre/html","title":"ul","content":"pub fn ul(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents an unordered list of items, typically rendered as a bulleted list.\n \nSynonyms:\nlustre/html.ul\nlustre/html ul","url":"lustre/html.html#ul"},{"doc":"lustre/html","title":"var","content":"pub fn var(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Represents the name of a variable in a mathematical expression or a\n programming context. It&#39;s typically presented using an italicized version of\n the current typeface, although that behavior is browser-dependent.\n \nSynonyms:\nlustre/html.var\nlustre/html var","url":"lustre/html.html#var"},{"doc":"lustre/html","title":"video","content":"pub fn video(attrs: List(Attribute(a)), children: List(Element(a))) -&gt; Element(\n  a,\n)\n Embeds a media player which supports video playback into the document. You\n can also use &lt;video&gt; for audio content, but the audio element may provide a\n more appropriate user experience.\n \nSynonyms:\nlustre/html.video\nlustre/html video","url":"lustre/html.html#video"},{"doc":"lustre/html","title":"wbr","content":"pub fn wbr(attrs: List(Attribute(a))) -&gt; Element(a)\n Represents the name of a variable in a mathematical expression or a\n programming context. It&#39;s typically presented using an italicized version of\n the current typeface, although that behavior is browser-dependent.\n \nSynonyms:\nlustre/html.wbr\nlustre/html wbr","url":"lustre/html.html#wbr"},{"doc":"lustre/html","title":"lustre/html","content":"","url":"lustre/html.html"}]);